@@ -17,7 +17,7 @@
 
 package Lemonldap::NG::Manager::Build::Tree;
 
-our $VERSION = '2.17.0';
+our $VERSION = '2.18.0';
 
 sub tree {
     return [ {
@@ -401,6 +401,7 @@ sub tree {
                                 'radiusAuthnLevel',
                                 'radiusSecret',
                                 'radiusServer',
+                                'radiusTimeout',
                                 'radiusExportedVars',
                                 'radiusDictionaryFile',
                                 'radiusRequestAttributes',
@@ -579,6 +580,7 @@ sub tree {
                     help  => 'sessions.html',
                     nodes => [
                         'storePassword',
+                        'storePasswordEncrypted',
                         'displaySessionId',
                         'timeout',
                         'timeoutActivity',
@@ -738,9 +740,10 @@ sub tree {
                         'autoSigninRules',
                         {
                             title => 'stayConnect',
-                            help  => 'stayconnected.html',
+                            help  => 'trustedbrowser.html',
                             form  => 'simpleInputContainer',
                             nodes => [
+                                'trustedBrowserRule',
                                 'stayConnected',
                                 'stayConnectedBypassFG',
                                 'stayConnectedTimeout',
@@ -906,6 +909,15 @@ sub tree {
                             nodes =>
                               [ 'decryptValueRule', 'decryptValueFunctions', ]
                         },
+                        {
+                            title => 'initializePasswordResetLabel',
+                            help  => 'initializePasswordReset.html',
+                            form  => 'simpleInputContainer',
+                            nodes => [
+                                'initializePasswordReset',
+                                'initializePasswordResetSecret',
+                            ],
+                        },
                         {
                             title => 'customPluginsNode',
                             help  => 'plugincustom.html',
@@ -970,6 +982,8 @@ sub tree {
                                 'webauthn2fSelfRegistration',
                                 'webauthn2fUserCanRemoveKey',
                                 'webauthn2fUserVerification',
+                                'webauthn2fAttestation',
+                                'webauthn2fAttestationTrust',
                                 'webauthnRpName',
                                 'webauthnDisplayNameAttr',
                                 'webauthn2fAuthnLevel',
@@ -1146,6 +1160,16 @@ sub tree {
                                         'checkHIBPRequired'
                                     ],
                                 },
+                                {
+                                    title => 'Entropycheck',
+                                    help  => 'checkentropy.html',
+                                    form  => 'simpleInputContainer',
+                                    nodes => [
+                                        'checkEntropy',
+                                        'checkEntropyRequired',
+                                        'checkEntropyRequiredLevel'
+                                    ],
+                                },
                                 {
                                     title => 'newLocationWarnings',
                                     help  => 'newlocationwarning.html',
@@ -1458,17 +1482,38 @@ sub tree {
                     help  => 'openidconnectservice.html#security',
                     nodes => [ {
                             title => 'oidcServiceMetaDataKeys',
-                            form  => 'RSACertKeyNoPassword',
-                            group => [
-                                'oidcServicePrivateKeySig',
-                                'oidcServicePublicKeySig',
-                                'oidcServiceKeyIdSig',
-                                'oidcServiceOldPrivateKeySig',
-                                'oidcServiceOldPublicKeySig',
-                                'oidcServiceOldKeyIdSig',
-                                'oidcServiceNewPrivateKeySig',
-                                'oidcServiceNewPublicKeySig',
-                                'oidcServiceNewKeyIdSig',
+                            nodes => [ {
+                                    title => 'oidcServiceMetaDataSigKeys',
+                                    form  => 'OidcKey',
+                                    group => [
+                                        'oidcServicePrivateKeySig',
+                                        'oidcServicePublicKeySig',
+                                        'oidcServiceKeyIdSig',
+                                        'oidcServiceKeyTypeSig',
+                                        'oidcServiceOldPrivateKeySig',
+                                        'oidcServiceOldPublicKeySig',
+                                        'oidcServiceOldKeyIdSig',
+                                        'oidcServiceOldKeyTypeSig',
+                                        'oidcServiceNewPrivateKeySig',
+                                        'oidcServiceNewPublicKeySig',
+                                        'oidcServiceNewKeyIdSig',
+                                        'oidcServiceNewKeyTypeSig',
+                                    ],
+                                },
+                                {
+                                    title => 'oidcServiceMetaDataEncKeys',
+                                    form  => 'OidcKey',
+                                    group => [
+                                        'oidcServicePrivateKeyEnc',
+                                        'oidcServicePublicKeyEnc',
+                                        'oidcServiceKeyIdEnc',
+                                        'oidcServiceKeyTypeEnc',
+                                        'oidcServiceOldPrivateKeyEnc',
+                                        'oidcServiceOldPublicKeyEnc',
+                                        'oidcServiceOldKeyIdEnc',
+                                        'oidcServiceOldKeyTypeEnc',
+                                    ],
+                                },
                             ],
                         },
                         'oidcServiceAllowAuthorizationCodeFlow',
@@ -1477,6 +1522,8 @@ sub tree {
                         'oidcServiceIgnoreScopeForClaims',
                         'oidcServiceAllowOnlyDeclaredScopes',
                         'oidcDropCspHeaders',
+                        'oidcServiceEncAlgorithmAlg',
+                        'oidcServiceEncAlgorithmEnc',
                     ],
                 },
                 {
