@@ -26,7 +26,7 @@ use JSON 'to_json';
 use Lemonldap::NG::Common::Conf::ReConstants;
 use Lemonldap::NG::Manager::Attributes;
 
-our $VERSION = '2.0.12';
+our $VERSION = '2.18.0';
 
 extends 'Lemonldap::NG::Common::Conf::Compact';
 
@@ -359,8 +359,12 @@ sub _scanNodes {
                         $self->set( $target, $key, $leaf->{title},
                             $leaf->{data} );
                     }
+                    elsif ( !@$subNodes ) {
+                        hdebug("  $target: no subnodes");
+                        $self->confChanged(1);
+                    }
                     else {
-                        hdebug("  $target: looking for subnodes");
+                        hdebug("  $target: scanning subnodes");
                         $self->_scanNodes($subNodes);
                     }
                 }
@@ -433,8 +437,12 @@ sub _scanNodes {
                         }
                         $self->set( $target, $key, $leaf->{title}, $tmp );
                     }
+                    elsif ( !@$subNodes ) {
+                        hdebug("  $target: no subnodes");
+                        $self->confChanged(1);
+                    }
                     else {
-                        hdebug("  $target: looking for subnodes");
+                        hdebug("  $target: scanning subnodes");
                         $self->_scanNodes($subNodes);
                     }
                 }
@@ -453,8 +461,12 @@ sub _scanNodes {
                         $self->set( $target, $key, $leaf->{title},
                             $leaf->{data} );
                     }
+                    elsif ( !@$subNodes ) {
+                        hdebug("  $target: no subnodes");
+                        $self->confChanged(1);
+                    }
                     else {
-                        hdebug("  $target: looking for subnodes");
+                        hdebug("  $target: scanning subnodes");
                         $self->_scanNodes($subNodes);
                     }
                 }
@@ -472,8 +484,12 @@ sub _scanNodes {
                             $self->set( $target, $key, $leaf->{title},
                                 $leaf->{data} );
                         }
+                        elsif ( !@$subNodes ) {
+                            hdebug("  $target: no subnodes");
+                            $self->confChanged(1);
+                        }
                         else {
-                            hdebug("  $target: looking for subnodes");
+                            hdebug("  $target: scanning subnodes");
                             $self->_scanNodes($subNodes);
                         }
                     }
@@ -524,8 +540,12 @@ sub _scanNodes {
                         $self->set( $target, $key, $leaf->{title},
                             $leaf->{data} );
                     }
+                    elsif ( !@$subNodes ) {
+                        hdebug("  $target: no subnodes");
+                        $self->confChanged(1);
+                    }
                     else {
-                        hdebug("  $target: looking for subnodes");
+                        hdebug("  $target: scanning subnodes");
                         $self->_scanNodes($subNodes);
                     }
                 }
@@ -543,8 +563,12 @@ sub _scanNodes {
                             $self->set( $target, $key, $leaf->{title},
                                 $leaf->{data} );
                         }
+                        elsif ( !@$subNodes ) {
+                            hdebug("  $target: no subnodes");
+                            $self->confChanged(1);
+                        }
                         else {
-                            hdebug("  $target: looking for subnodes");
+                            hdebug("  $target: scanning subnodes");
                             $self->_scanNodes($subNodes);
                         }
                     }
@@ -870,8 +894,9 @@ sub _scanNodes {
                     foreach my $node ( @{ $leaf->{nodes} } ) {
                         my $tmp;
                         $tmp->{$_} = $node->{data}->{$_}
-                          foreach (qw(type rule logo level label));
-                        $tmp->{over} = {};
+                          foreach (qw(type rule logo level label regrule));
+                        $tmp->{register} = $node->{data}->{register} ? 1 : 0;
+                        $tmp->{over}     = {};
                         foreach ( @{ $node->{data}->{over} } ) {
                             $tmp->{over}->{ $_->[0] } = $_->[1];
                         }
